pub struct BatchHandle {
pub id: String,
pub status: i32,
pub counts: Option<BatchCounts>,
pub created_at: Option<i64>,
pub expires_at: Option<i64>,
pub ended_at: Option<i64>,
pub endpoint: Option<String>,
}Fields
id: Stringstatus: i32counts: Option<BatchCounts>created_at: Option<i64>expires_at: Option<i64>ended_at: Option<i64>endpoint: Option<String>e.g. “/v1/chat/completions”
Implementations
Sourceimpl BatchHandle
impl BatchHandle
Sourcepub fn status(&self) -> BatchStatus
pub fn status(&self) -> BatchStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: BatchStatus)
pub fn set_status(&mut self, value: BatchStatus)
Sets status to the provided enum value.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn expires_at(&self) -> i64
pub fn expires_at(&self) -> i64
Returns the value of expires_at, or the default value if expires_at is unset.