pub struct FunctionDef {
pub name: String,
pub description: Option<String>,
pub parameters: Option<String>,
}Expand description
A function the model MAY call. parameters is a raw JSON Schema string.
Fields
name: Stringdescription: Option<String>parameters: Option<String>raw JSON object
Implementations
Sourceimpl FunctionDef
impl FunctionDef
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn parameters(&self) -> &str
pub fn parameters(&self) -> &str
Returns the value of parameters, or the default value if parameters is unset.