pub struct TranscriptionRequest {
pub model: String,
pub language: Option<String>,
pub prompt: Option<String>,
pub response_format: Option<String>,
pub temperature: Option<f32>,
}Expand description
The audio file itself is sent as the multipart file part, NOT in this message;
these are the accompanying form fields.
Fields
model: Stringlanguage: Option<String>ISO-639-1 hint
prompt: Option<String>decoding bias
response_format: Option<String>json|text|verbose_json|srt|vtt
temperature: Option<f32>Implementations
Sourceimpl TranscriptionRequest
impl TranscriptionRequest
Sourcepub fn language(&self) -> &str
pub fn language(&self) -> &str
Returns the value of language, or the default value if language is unset.
Sourcepub fn prompt(&self) -> &str
pub fn prompt(&self) -> &str
Returns the value of prompt, or the default value if prompt is unset.
Sourcepub fn response_format(&self) -> &str
pub fn response_format(&self) -> &str
Returns the value of response_format, or the default value if response_format is unset.
Sourcepub fn temperature(&self) -> f32
pub fn temperature(&self) -> f32
Returns the value of temperature, or the default value if temperature is unset.